desmod
======

The desmod package provides a pythonic environment for composing
Discrete Event Simulation MODels. The excellent `SimPy`__ package
provides the discrete event simulation kernel. Desmod provides
additional capabilities useful for composing, monitoring, configuring,
and simulating arbitrarily complex models.

__ https://simpy.readthedocs.io/en/latest/

.. image:: https://readthedocs.org/projects/desmod/badge/?version=latest
    :target: https://desmod.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/SanDisk-Open-Source/desmod/workflows/CI/badge.svg
   :target: https://github.com/SanDisk-Open-Source/desmod/actions?query=workflow%3ACI
    :alt: Build Status

.. image:: https://coveralls.io/repos/github/SanDisk-Open-Source/desmod/badge.svg?branch=master
    :target: https://coveralls.io/github/SanDisk-Open-Source/desmod?branch=master
    :alt: Code Coverage


Installation
------------

Desmod is available on PyPI and can be installed with `pip`::

    pip install desmod


Resources
---------

* `Documentation on ReadTheDocs <http://desmod.readthedocs.io/>`_
* `Questions and development discussion Google Group
  <https://groups.google.com/forum/?hl=en#!forum/desmod>`_
* `Source code, issue tracker, and CI on GitHub
  <https://github.com/SanDisk-Open-Source/desmod>`_
* `Package on PyPI <https://pypi.python.org/pypi/desmod>`_
